<?php
namespace Modules\Relatorio\Services;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource;
use Teknisa\Model\Suprimentos\Entities\Prmarcpedcol;
use Teknisa\Model\Suprimentos\Entities\Itempedcol;
use Teknisa\Model\Suprimentos\Entities\Pedcolgeral;
use Teknisa\Model\Geral\Entities\Lista;
use \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use \Zeedhi\Framework\DB\StoredProcedure\Param;

class Sup03100EvolucaoPrecosService {

    protected $entityManager;
    protected $environment;
    protected $dataSourceManager;
    protected $newCode;

    public function __construct(EntityManager $entityManager, $environment, DataSource\Manager $dataSourceManager, $newCode) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->newCode = $newCode;
    }

    public function iniciaTransacao() {
        $this->entityManager->beginTransaction();
    }

    public function commit() {
        $this->entityManager->commit();
    }

    public function flush() {
        $this->entityManager->flush();
    }

    public function rollback() {
        $this->entityManager->rollback();
    }
    
    public function setTrabEvolPrec($conditions) {
        try {
	        $this->iniciaTransacao();
	        
            $connection = $this->entityManager->getConnection();
            $sql = "INSERT INTO TRABEVOLPREC (NREVOLPRECO,CDPRODUTO,DTINIPEREVOL, DTFINPEREVOL,VRPRECOEVOL,IDREGEVOLINC, NRORG) SELECT :P_NREVOLPRECO, PRODENTR.CDPRODESTO, PERIODO.DATAINI, PERIODO.DATAFIN, SUM(VRPRECUNI)/SUM(QTPRODEST) AS VRFINAL, 'N' AS IDREGEVOLINC, PRODENTR.NRORG FROM (  SELECT TO_DATE(:P_DTINI) DATAINI, (TO_DATE(:P_DTINI) + (:P_NRPERI * 1)) -1 DATAFIN FROM DUAL UNION SELECT TO_DATE(:P_DTINI) + (:P_NRPERI * 1) DATAINI, (TO_DATE(:P_DTINI) + (:P_NRPERI * 2)) - 1 DATAFIN FROM DUAL UNION SELECT TO_DATE(:P_DTINI) + (:P_NRPERI * 2) DATAINI, (TO_DATE(:P_DTINI) + (:P_NRPERI * 3)) - 1 DATAFIN FROM DUAL UNION SELECT TO_DATE(:P_DTINI) + (:P_NRPERI * 3) DATAINI, (TO_DATE(:P_DTINI) + (:P_NRPERI * 4)) - 1 DATAFIN FROM DUAL ) PERIODO, (  SELECT PRODUTO.CDPRODESTO, ITEMAUTF.DTPROGENTAF, SUM(ITEMAUTF.QTPROGENTAF * PRODUTO.VRFATOCONV) QTPRODEST, SUM(ITEMAUTF.QTPROGENTAF * ITEMAUTF.VRPREUNIAF) VRPRECUNI, ITEMAUTF.NRORG FROM ITEMAUTF INNER JOIN AUTOFORNE ON ITEMAUTF.CDFILDEST  = AUTOFORNE.CDFILDEST AND ITEMAUTF.CDFILLANC  = AUTOFORNE.CDFILLANC AND ITEMAUTF.NRAUTOFORN = AUTOFORNE.NRAUTOFORN AND ITEMAUTF.NRORG      = AUTOFORNE.NRORG INNER JOIN FILIAL    ON FILIAL.CDFILIAL     = ITEMAUTF.CDFILDEST AND FILIAL.NRORG        = ITEMAUTF.NRORG INNER JOIN PRODUTO   ON ITEMAUTF.CDPRODUTO  = PRODUTO.CDPRODUTO AND ITEMAUTF.NRORG      = PRODUTO.NRORG WHERE FILIAL.CDREGIAO = :P_CDREGIAO AND PRODUTO.CDARVPROD BETWEEN :P_CDPRODINI AND RPAD(:P_CDPRODFIN, 20, 'Z') AND ITEMAUTF.DTPROGENTAF BETWEEN :P_DTINI AND :P_DTFIN AND ((AUTOFORNE.IDAUTOFORNEX = 'N' AND :P_AFEXTRA = 'N') OR (AUTOFORNE.IDAUTOFORNEX = 'S' AND :P_AFEXTRA = 'S')) AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '5' AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '6' AND NVL(AUTOFORNE.IDBAIXAAF, '0') <> '4' GROUP BY PRODUTO.CDPRODESTO, ITEMAUTF.DTPROGENTAF, ITEMAUTF.NRORG ) PRODENTR WHERE PRODENTR.DTPROGENTAF BETWEEN PERIODO.DATAINI AND PERIODO.DATAFIN AND PRODENTR.NRORG = :NRORG GROUP BY PRODENTR.CDPRODESTO, PERIODO.DATAINI, PERIODO.DATAFIN, PRODENTR.NRORG";
            $query = $this->entityManager->getConnection()->prepare($sql);
            
            $stProximoCodigo = $this->newCode->getCodeByTableName('EVOLPRECO', $this->environment->getNrOrg());
            
            $query->bindValue("P_DTINI",        $conditions['DTPERIOINI']);
            $query->bindValue("P_DTFIN",        $conditions['DTPERIOFIN']);
            $query->bindValue("P_NRPERI",       $conditions['NRPERIODO']);
            $query->bindValue("P_CDREGIAO",     $conditions['CDREGIAO']);
            $query->bindValue("P_CDPRODINI",    $conditions['CDPRODINI']);
            $query->bindValue("P_CDPRODFIN",    $conditions['CDPRODFIN']);
            $query->bindValue("P_AFEXTRA",      $conditions['IDAFEXTRA']);
            $query->bindValue("P_NREVOLPRECO",  $stProximoCodigo);
            $query->bindValue("NRORG",          $this->environment->getNrOrgTrab());
            
            $query->execute();
            $this->commit();
            
            return $stProximoCodigo;
            
        } catch (\Exception $e) {
		    $this->rollback();
		    throw $e;
		}
    }
    
    public function getConditionsFromFilter($filter) {
        try {
            $conditions = array();
            foreach($filter->getConditions() as $filter) {
                if(is_array($filter['value'])) 
                    $conditions[$filter['columnName']] = implode("_", $filter['value']) . '_';
                else 
                    $conditions[$filter['columnName']] = $filter['value'];
            }
            return $conditions;   
        } catch (\Exception $e) {
		    throw $e;
		}
    }
    
    public function setEvolucaoPrecos($nrevolpreco, $conditions) {
        try {
	        $this->iniciaTransacao();
	    
            $procedure = new StoredProcedure($this->entityManager->getConnection(), 'EVOLUCAO_PRECOS');
            $procedure->addParam(new Param('P_NREVOLPRECO', Param::PARAM_INPUT,  $nrevolpreco,              Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTINI',       Param::PARAM_INPUT,  $conditions['DTPERIOINI'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_DTFIN',       Param::PARAM_INPUT,  $conditions['DTPERIOFIN'], Param::PARAM_TYPE_STR));
            $procedure->addParam(new Param('P_NRPERI',      Param::PARAM_INPUT,  $conditions['NRPERIODO'],  Param::PARAM_TYPE_STR));
    
            $procedure->execute();
            
            $this->commit();
            
        } catch (\Exception $e) {
		    $this->rollback();
		    throw $e;
		}
    }
    
    public function getEvolucaoPrecosProduto($nrevolpreco) {
        try {
            $sql = "SELECT :P_NREVOLPRECO AS NREVOLPRECO, TRABEVOLPREC.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, TRABEVOLPREC.NREVOLPRECO, TRABEVOLPREC.IDREGEVOLINC, TRABEVOLPREC.NRORG FROM PRODUTO INNER JOIN TRABEVOLPREC ON TRABEVOLPREC.CDPRODUTO = PRODUTO.CDPRODUTO AND TRABEVOLPREC.NRORG     = PRODUTO.NRORG WHERE TRABEVOLPREC.NREVOLPRECO = :P_NREVOLPRECO AND TRABEVOLPREC.NRORG = :NRORG GROUP BY TRABEVOLPREC.CDPRODUTO, PRODUTO.CDARVPROD, PRODUTO.NMPRODUTO, TRABEVOLPREC.NREVOLPRECO, TRABEVOLPREC.IDREGEVOLINC, TRABEVOLPREC.NRORG ORDER BY PRODUTO.CDARVPROD";
        
            $params = array(
                "P_NREVOLPRECO" => $nrevolpreco,
                "NRORG" => $this->environment->getNrOrgTrab()
            );
            
        	return $this->entityManager->getConnection()->fetchAll($sql, $params);    
        } catch (\Exception $e) {
		    throw $e;
		}
    }

    public function atualizaPrecObj($produto){
        $prmarcpedcol = $this->entityManager->getRepository('Teknisa\Model\Suprimentos\Entities\Prmarcpedcol')
            ->findOneBy(
                array(
                    "nrorg"       => $produto['NRORG'],
                    "cdfilial"    => $produto['CDFILIAL'],
                    "nrpedidocol" => $produto['NRPEDIDOCOL'],
                    "cdproduto"   => $produto['CDPRODUTO'],
                    "cdmarca"     => $produto['CDMARCA']
                )
            );
            
        if ($prmarcpedcol instanceof Prmarcpedcol) {
            $prmarcpedcol->setDsobsrenegocia($produto['DSOBSRENEGOCIA']);
            $prmarcpedcol->setVrprecoobjetivo($produto['VRPRECOOBJETIVO']);
            $prmarcpedcol->setNrorgultatu($produto['NRORG']);
            $prmarcpedcol->setIditpedprioneg($produto['IDITPEDPRIONEG']);
            $prmarcpedcol->setDtultatu(new \DateTime());
            $prmarcpedcol->setCdoperultatu($this->environment->getCdoperador());
            
            $this->entityManager->persist($prmarcpedcol);
        }
    }
    
    public function atualizaPrecObjItmPedCol($produto){
        $pedcoleta = $this->entityManager->getRepository('Teknisa\Model\Suprimentos\Entities\Pedcoleta')
            ->findBy(
                array(
                    "nrorg"           => $produto['NRORG'],
                    "cdfilial"        => $produto['CDFILIAL'],
                    "nrpedidocol"     => $produto['NRPEDIDOCOL'],
                    "cdforneced"      => $produto['CDFORNECED']
                )
            );
        
        foreach ($pedcoleta as $item) {
            $itempedcol = $this->entityManager->getRepository('Teknisa\Model\Suprimentos\Entities\Itempedcol')
                ->findOneBy(
                    array(
                        "nrorg"           => $produto['NRORG'],
                        "cdfilial"        => $produto['CDFILIAL'],
                        "nrpedcoleta"     => $item->getNrpedcoleta(),
                        "cdproduto"       => $produto['CDPRODUTO'],
                        "cdmarca"         => $produto['CDMARCA'],
                        "cdforneced"      => $produto['CDFORNECED'],
                        "cdregiao"        => $item->getCdregiao()
                    )
                );
                
            if ($itempedcol instanceof Itempedcol) {
                $itempedcol->setVrprecoobjetivo($produto['VRPRECOOBJETIVO']);
                $itempedcol->setDsobsrenegocia($produto['DSOBSRENEGOCIA']);
                $itempedcol->setIditpedprioneg($produto['IDITPEDPRIONEG']);
                $itempedcol->setNrorgultatu($produto['NRORG']);
                $itempedcol->setDtultatu(new \DateTime());
                $itempedcol->setCdoperultatu($this->environment->getCdoperador());
                
                $this->entityManager->persist($itempedcol);
            }
        }
    }
    
    public function preencheGrafico($produto){
        $connection = $this->entityManager->getConnection();
        $sql = "INSERT INTO HISTNEGOCIAPCOL( 
                    NRHISTNEGOCIAPCOL,
                    CDFILIAL, NRPEDIDOCOL, DTINIVALPCOL, DTFINVALPCOL, CDCOMPRADOR, 
                    DSOBSRENEGOCIA, CDPRODUTO, CDMARCA, VRUNITATUAL, VRPRECRENEG, 
                    VROBJATUAL, IDITPEDPRIONEG, DTOPERHISTPCOL, CDOPERRESP, 
                    DTINCLUSAO, NRORG) 
                VALUES ( 
                    SEQ_HISTNEGOCIAPCOL.NEXTVAL, 
                    :CDFILIAL, :NRPEDIDOCOL, :DTINIVALPCOL, :DTFINVALPCOL, :CDCOMPRADOR, 
                    :DSOBSRENEGOCIA, :CDPRODUTO, :CDMARCA, :VRUNITATUAL, :VRPRECRENEG, 
                    :VROBJATUAL, :IDITPEDPRIONEG, TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI:SS'), :CDOPERRESP, 
                    TO_CHAR(SYSDATE, 'DD/MM/YYYY HH24:MI:SS'), :NRORG)";
            
        $query = $this->entityManager->getConnection()->prepare($sql);
        
        $query->bindValue("CDFILIAL",       $produto['CDFILIAL']);
        $query->bindValue("NRPEDIDOCOL",    $produto['NRPEDIDOCOL']);
        $query->bindValue("DTINIVALPCOL",   $produto['DTINIPERCOT']);
        $query->bindValue("DTFINVALPCOL",   $produto['DTFINPERCOT']);
        $query->bindValue("CDCOMPRADOR",    $produto['COMPRADOR']);
        $query->bindValue("DSOBSRENEGOCIA", $produto['DSOBSRENEGOCIA']);
        $query->bindValue("CDPRODUTO",      $produto['CDPRODUTO']);
        $query->bindValue("CDMARCA",        $produto['CDMARCA']);
        $query->bindValue("VRUNITATUAL",    $produto['VRPRECUNIT']);
        $query->bindValue("VRPRECRENEG",    $produto['VRPRECREN']);
        $query->bindValue("VROBJATUAL",     $produto['VRPRECOOBJETIVO']);
        $query->bindValue("IDITPEDPRIONEG", $produto['IDITPEDPRIONEG']);
        $query->bindValue("CDOPERRESP",     $this->environment->getCdOperador());
        $query->bindValue("NRORG",          $this->environment->getNrOrgTrab());
        
        $query->execute();
    }

    public function atualizaSituPedcolgeral($pedido, $dtExpirapedcol){
        $pedcolgeral = $this->entityManager->getRepository('Teknisa\Model\Suprimentos\Entities\Pedcolgeral')
            ->findOneBy(
                array(
                    "nrorg"       => $this->environment->getNrOrgTrab(),
                    "cdfilial"    => $pedido['CDFILIAL'],
                    "nrpedidocol" => $pedido['NRPEDGRID']
                )
            );
            
        if ($pedcolgeral instanceof Pedcolgeral) {
            $pedcolgeral->setIdrenegociapcol($pedido['IDRENEGOCIAPCOL']);
            $pedcolgeral->setIdsitupedcoleta($pedido['IDSITUCOLETAGERAL']);
            $pedcolgeral->setDtexpirapedcol(new \DateTime(str_replace('/', '-', $dtExpirapedcol)));
            $pedcolgeral->setNrorgultatu($this->environment->getNrOrgTrab());
            $pedcolgeral->setDtultatu(new \DateTime());
            $pedcolgeral->setCdoperultatu($this->environment->getCdoperador());

            $this->entityManager->persist($pedcolgeral);
        }
    } 

    public function atualizaSituPedcoleta($pedido){
        $listaPedcoleta = $this->entityManager->getRepository('Teknisa\Model\Suprimentos\Entities\Pedcoleta')
            ->findBy(
                array(
                    "nrorg"       => $this->environment->getNrOrgTrab(),
                    "nrpedidocol" => $pedido['NRPEDGRID']
                )
            );

        foreach ($listaPedcoleta as $pedcoleta) {
            if ($pedcoleta instanceof Pedcoleta) {
                $pedcoleta->setIdsitupedcol($pedido['IDSITUPEDCOL']);
                $pedcoleta->setNrorgultatu($this->environment->getNrOrgTrab());
                $pedcoleta->setDtultatu(new \DateTime());
                $pedcoleta->setCdoperultatu($this->environment->getCdoperador());
                
                $this->entityManager->persist($pedcoleta);
            }
        }
    }  

    public function geraCotacao($nrpedcoleta, $cdforneced, $cdregiao, $cdfilial, $nrsemini, $nrsemifin, $entralista){
        $connection = $this->entityManager->getConnection();
        
        $procedure = new StoredProcedure($connection, 'GRAVA_COTWEB');
        $procedure->addParam(new Param('P_CDFILIAL',    Param::PARAM_INPUT,  $cdfilial,    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRPEDCOLETA', Param::PARAM_INPUT,  $nrpedcoleta, Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDREGIAO',    Param::PARAM_INPUT,  $cdregiao,    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_CDFORNECED',  Param::PARAM_INPUT,  $cdforneced,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEMINI',    Param::PARAM_INPUT,  $nrsemini,    Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_NRSEMFIN',    Param::PARAM_INPUT,  $nrsemifin,   Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_ENTRALISTA',  Param::PARAM_INPUT,  $entralista,  Param::PARAM_TYPE_STR));
        $procedure->addParam(new Param('P_COTA_N_GER',  Param::PARAM_OUTPUT, NULL,         Param::PARAM_TYPE_STR));
        
        return $procedure->execute();
    }
    
    public function retornaLogoEcommerce() {
		$sql = "SELECT URLLOGO FROM APPCONFIG WHERE IDAPLICATIVO = 'PORTAL E-COMMERCE' AND NRORG = :P_NRORG";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array(
                "P_NRORG" => $this->environment->getNrorgTrab()
            )
        );
		$result = $stmt->fetchAll();
		if(isset($result[0]) && $result[0]['URLLOGO'] && $result != null && $result != ''){
    		$logoSrc = $this->fileServerURL.$result[0]['URLLOGO'];
    		return $logoSrc;
        }else{
            return false;
        }
    }
    
    public function retornaMenorMaiorProdutoPedido($pedidos) {
		$sql = "SELECT DISTINCT CDPRODUTO
		          FROM PRMARCPEDCOL
		         WHERE (INSTR(:FILIALNRPEDIDOCOL, CONCAT(CDFILIAL, NRPEDIDOCOL)) <> 0)
		           AND NRORG = :NRORG
		         ORDER BY CDPRODUTO";
        
        $params = array(
            "FILIALNRPEDIDOCOL" => $pedidos['FILIALNRPEDIDOCOL'],
            "NRORG"             => $this->environment->getNrOrgTrab()
        );
        
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
    
    public function retornaProdutosValorMinimo($consideraMarca, $nrlista) {
		$sql = "SELECT
                 TO_CHAR(MIN((CASE NVL(PRMARCPEDCOL.VRPRECREN,0)
                     WHEN 0   THEN PRMARCPEDCOL.VRPRECUNIPRMARC
                     ELSE PRMARCPEDCOL.VRPRECREN
                 END) / PRODUTO.VRFATOCONV)) AS VRPRECUNIPRMARC,
                 PRMARCPEDCOL.CDPRODUTO,
                 DECODE('".$consideraMarca."','S',PRMARCPEDCOL.CDMARCA,'*****') CDMARCA,
                 PRODUTO.VRFATOCONV
             FROM
                 PRMARCPEDCOL,
                 LISTA,
                 PRODUTO
             WHERE
                 LISTA.NRLISTA =:NRLISTA
                 AND PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                 AND PRMARCPEDCOL.NRORG = LISTA.NRORG
                 AND PRMARCPEDCOL.VRPRECUNIPRMARC > 0
                 AND PRMARCPEDCOL.NRORG =:NRORG
                 AND PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO
             GROUP BY
                 PRMARCPEDCOL.CDPRODUTO,
                 DECODE('".$consideraMarca."','S',PRMARCPEDCOL.CDMARCA,'*****'),
                 PRODUTO.VRFATOCONV";
        
        $params = array(
            "NRLISTA"           => $nrlista,
            "NRORG"             => $this->environment->getNrOrgTrab()
        );
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	
	public function retornaPedido($produtoValorMinimo, $nrlista) {
	    
		$sql = "SELECT PRMARCPEDCOL.CDFILIAL, PRMARCPEDCOL.NRPEDIDOCOL, PRMARCPEDCOL.CDPRODUTO, PRMARCPEDCOL.VRPRECUNIPRMARC, :MELHORPRECO * PRODUTO.VRFATOCONV,
                    PRODUTO.VRFATOCONV FROM PRMARCPEDCOL, LISTA, PRODUTO
                    WHERE LISTA.NRLISTA = :NRLISTA
                       AND PRMARCPEDCOL.CDFILIAL||PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                       AND PRMARCPEDCOL.CDPRODUTO = :CDPRODUTO
                       AND PRMARCPEDCOL.VRPRECUNIPRMARC = ROUND((:MELHORPRECO * PRODUTO.VRFATOCONV),8)
                       AND PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO";
        
        $params = array(
            "NRLISTA"           => $nrlista,
            "MELHORPRECO"       => $produtoValorMinimo['VRPRECUNIPRMARC'],
            "CDPRODUTO"         => $produtoValorMinimo['CDPRODUTO']
        );
     
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute($params);
        $pedido = $stmt->fetchAll();
        
        $this->atualizaMelhorPedido($pedido);
	}
	
	public function atualizaMelhorPedido($pedido) {
	    try {
	        $this->iniciaTransacao();
    		$sql = "UPDATE PRMARCPEDCOL
                      SET IDMELHORPRECO = 'S'
                      WHERE CDFILIAL =:CDFILIAL
                        AND NRPEDIDOCOL =:NRPEDIDOCOL
                        AND CDPRODUTO =:CDPRODUTO";
          
            $params = array(
                "CDFILIAL"      => $pedido[0]['CDFILIAL'],
                "CDPRODUTO"     => $pedido[0]['CDPRODUTO'],
                "NRPEDIDOCOL"   => $pedido[0]['NRPEDIDOCOL']
            );
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute($params);
            
            $this->commit();
	    } catch (\Exception $e) {
		    $this->rollback();
		    throw $e;
		}
	 
	}
	
	public function atualizaPrecObjMinPrmarcpedcol($produtoValorMinimo, $nrpedidocol, $precoObjetivoNull = NULL){
	  
        try {
            $this->iniciaTransacao();
    	    if($precoObjetivoNull) {
    	        $sql = "UPDATE PRMARCPEDCOL
                    SET 
                    VRPRECOOBJETIVO = :VRPRECOOBJETIVO * :VRFATOCONV,
                        IDITPEDPRIONEG = :P_IDITPEDPRIONEG,
                        DSOBSRENEGOCIA = :DSOBSRENEGOCIA,
                        NRORGULTATU = :NRORGULTATU,
                        CDOPERULTATU = :CDOPERULTATU,
                        DTULTATU = TO_DATE(:DTULTATU, 'DD/MM/YYYY HH24:MI:SS')
                    WHERE CDPRODUTO = :CDPRODUTO
                      AND (CDMARCA = :CDMARCA OR TO_CHAR(:CDMARCA) = '*****')
                      AND (INSTR(:NRPEDIDOCOL, PRMARCPEDCOL.CDFILIAL||PRMARCPEDCOL.NRPEDIDOCOL) <> 0)";
                      
                $params = array(
                    "VRPRECOOBJETIVO"   => $produtoValorMinimo['VRPRECUNIPRMARC'],
                    "VRFATOCONV"        => $produtoValorMinimo['VRFATOCONV'],
                    "P_IDITPEDPRIONEG"  => $precoObjetivoNull,
                    "CDPRODUTO"         => $produtoValorMinimo['CDPRODUTO'],
                    "CDMARCA"           => $produtoValorMinimo['CDMARCA'],
                    "DSOBSRENEGOCIA"    => $produtoValorMinimo['DSOBSRENEGOCIA'],
                    "NRPEDIDOCOL"       => $nrpedidocol,
                    "NRORGULTATU"       => $this->environment->getNrorgTrab(),
                    "CDOPERULTATU"      => $this->environment->getCdoperador(),
                    "DTULTATU"          => $this->environment->getCurrentTime()->format("d/m/Y H:i:s")
                );
                     
    	    } else { 
    	        
                $sql = "UPDATE PRMARCPEDCOL
                        SET VRPRECOOBJETIVO = :VRPRECOOBJETIVO * :VRFATOCONV,
                            IDITPEDPRIONEG = (SELECT CASE
                                                          WHEN PRMARCPEDCOL.VRPRECUNIPRMARC > :VRPRECOOBJETIVO
                                                          THEN 'S'
                                                          ELSE 'N'
                                                       END 
                                                  FROM DUAL),
                            DSOBSRENEGOCIA = :DSOBSRENEGOCIA,
                            NRORGULTATU = :NRORGULTATU,
                            CDOPERULTATU = :CDOPERULTATU,
                            DTULTATU = TO_DATE(:DTULTATU, 'DD/MM/YYYY HH24:MI:SS')
                        WHERE CDPRODUTO = :CDPRODUTO
                          AND (CDMARCA = :CDMARCA OR TO_CHAR(:CDMARCA) = '*****')
                          AND (INSTR(:NRPEDIDOCOL, PRMARCPEDCOL.CDFILIAL||PRMARCPEDCOL.NRPEDIDOCOL) <> 0)";
                          
                $params = array(
                    "VRPRECOOBJETIVO"   => $produtoValorMinimo['VRPRECUNIPRMARC'],
                    "VRFATOCONV"        => $produtoValorMinimo['VRFATOCONV'],
                    "CDPRODUTO"         => $produtoValorMinimo['CDPRODUTO'],
                    "CDMARCA"           => $produtoValorMinimo['CDMARCA'],
                    "DSOBSRENEGOCIA"    => $produtoValorMinimo['DSOBSRENEGOCIA'],
                    "NRPEDIDOCOL"       => $nrpedidocol,
                    "NRORGULTATU"       => $this->environment->getNrorgTrab(),
                    "CDOPERULTATU"      => $this->environment->getCdoperador(),
                    "DTULTATU"          => $this->environment->getCurrentTime()->format("d/m/Y H:i:s")
                );
    	    }
        
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute($params);
        $this->commit();
	    } catch (\Exception $e) {
		    $this->rollback();
		    throw $e;
		}
	}
	
	public function atualizaPrecObjMinItempedcol($produtoValorMinimo, $nrpedidocol) {
	     
	    try {
            $this->iniciaTransacao();
            $sql = "UPDATE ITEMPEDCOL 
                       SET VRPRECOOBJETIVO = :VRPRECOOBJETIVO * :VRFATOCONV,
                           IDITPEDPRIONEG = (SELECT CASE
                                                      WHEN VRITEMPEDCOL > :VRPRECOOBJETIVO
                                                      THEN 'S'
                                                      ELSE 'N'
                                                   END 
                                              FROM DUAL),
                           DSOBSRENEGOCIA = :DSOBSRENEGOCIA,
                           NRORGULTATU = :NRORGULTATU,
                           CDOPERULTATU = :CDOPERULTATU,
                            DTULTATU = TO_DATE(:DTULTATU, 'DD/MM/YYYY HH24:MI:SS')
                     WHERE CDPRODUTO = :CDPRODUTO
                       AND (CDMARCA = :CDMARCA OR TO_CHAR(:CDMARCA) = '*****')
                       AND CDFILIAL    IN (SELECT CDFILIAL FROM PEDCOLETA WHERE CDFILIAL||NRPEDIDOCOL = :NRPEDIDOCOL)
                       AND CDFORNECED  IN (SELECT DISTINCT CDFORNECED FROM PEDCOLETA WHERE CDFILIAL||NRPEDIDOCOL = :NRPEDIDOCOL) 
                       AND CDREGIAO    IN (SELECT CDREGIAO FROM PEDCOLETA WHERE CDFILIAL||NRPEDIDOCOL = :NRPEDIDOCOL) 
                       AND NRPEDCOLETA IN (SELECT NRPEDCOLETA FROM PEDCOLETA WHERE CDFILIAL||NRPEDIDOCOL = :NRPEDIDOCOL)";
                
            $params = array(
                    "VRPRECOOBJETIVO"   => $produtoValorMinimo['VRPRECUNIPRMARC'],
                    "VRFATOCONV"        => $produtoValorMinimo['VRFATOCONV'],
                    "NRORGULTATU"       => $this->environment->getNrorgTrab(),
                    "CDOPERULTATU"      => $this->environment->getCdoperador(),
                    "DTULTATU"          => $this->environment->getCurrentTime()->format("d/m/Y H:i:s"),
                    "CDMARCA"           => $produtoValorMinimo['CDMARCA'],
                    "CDPRODUTO"         => $produtoValorMinimo['CDPRODUTO'],
                    "DSOBSRENEGOCIA"    => $produtoValorMinimo['DSOBSRENEGOCIA'],
                    "NRPEDIDOCOL"       => $nrpedidocol
                );
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute($params);
            $this->commit();
	    } catch (\Exception $e) {
		    $this->rollback();
		    throw $e;
		}
        
	}
    
    public function defineCookieEmail($name, $value = "", $time = 0, $path = "/", $domain = "", $secure = false, $httponly = false) {
        setcookie($name, $value, $time, $path, $domain, $secure, $httponly);
    }
    
    public function retornaCookieEmail($name) {
        if(array_key_exists($name, $_COOKIE)){
            return $_COOKIE[$name];
        }
        
        return false;
    }
    
    public function insereLista($listaCdlista){
        $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrgTrab());
        
        $this->iniciaTransacao();
        
        foreach ($listaCdlista as $cdlista) {
            $lista = new Lista();
            
            $lista->setNrlista($nrlista);
            $lista->setCdlista($cdlista);
            $lista->setNrorg($this->environment->getNrOrgTrab());
            $lista->setNrorginclusao($this->environment->getNrOrgTrab());
            $lista->setCdoperinclusao($this->environment->getCdoperador());
            $lista->setDtinclusao(new \DateTime());
            $lista->setDtultatu(new \DateTime());
            $this->entityManager->persist($lista);
        }
        
        $this->flush();
        $this->commit();
        
        return $nrlista;
    }
    
    public function deletaLista($nrlista) {
        $listas = $this->entityManager->getRepository('Teknisa\Model\Geral\Entities\Lista')
            ->findBy(
                array(
                    "nrorg"         => $this->environment->getNrOrgTrab(),
                    "nrlista"       => $nrlista
                )
            );
        
        foreach($listas as $lista){
            if ($lista instanceof Lista) {
                $this->entityManager->remove($lista);
                $this->flush();
            }
        }            
        
    }
    
    public function salvarComentario ($row, $regiao = false) {
        if($regiao){
            $stringPos   = '<br>';
            $pos      = strpos($row['TXCOMENTARIO'], $stringPos);
            $text = substr_replace($row['TXCOMENTARIO'], ' ' , $pos, strlen($stringPos));
            
            $stringReplace = array("<br>");
            $string   = array(", ");
            
            $row['TXCOMENTARIO'] = str_replace($stringReplace, $string, $text);
                                
        }
        if (isset($row["fileUpload"]) && isset($row["fileUpload"][0]) && isset($row["fileUpload"][0]["name"]) && isset($row["fileUpload"][0]["path"])){
            $dsDocumento = $row["fileUpload"][0]["name"];
            $documento = $row["fileUpload"][0]["path"];
        }else{
            $dsDocumento = ' ';
            $documento = ' ';
        }
        $cdFilial = isset($row['CDFILIAL']) ? $row['CDFILIAL'] : $row['pedidosSelecionados'][0]['CDFILIAL'];
        $nrPedidoCol = isset($row['NRPEDIDOCOL']) ? $row['NRPEDIDOCOL'] : $row['pedidosSelecionados'][0]['NRPEDIDOCOL'];
        $sql = "INSERT INTO COMENTPEDCOL ( CDFILIAL, NRPEDIDOCOL, DTCOMENTARIO, CDOPERADOR, TXCOMENTARIO, DTINCLUSAO, DTULTATU, NRORG, DSDOCUMENTOANEXO, DSIDDOCFILESERV ) VALUES ( :P_CDFILIAL, :P_NRPEDIDOCOL, SYSDATE, :P_CDOPERADOR, :P_TXCOMENTARIO, SYSDATE, SYSDATE, :NRORG, :DSDOCUMENTOANEXO, :DSIDDOCFILESERV )";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array(
                "P_CDFILIAL"     => $cdFilial,
                "P_NRPEDIDOCOL"  => $nrPedidoCol,
                "P_CDOPERADOR"   => $this->environment->getCdOperador(),
                "P_TXCOMENTARIO" => $row['TXCOMENTARIO'],
                "NRORG"   => $this->environment->getNrOrgTrab(),
                "DSDOCUMENTOANEXO" => $dsDocumento,
                "DSIDDOCFILESERV" => $documento
            )
        );

    }
    
    public function infoComentario($row) {
        $cdFilial = isset($row['CDFILIAL']) ? $row['CDFILIAL'] : $row['pedidosSelecionados'][0]['CDFILIAL'];
        $nrPedidoCol = isset($row['NRPEDIDOCOL']) ? $row['NRPEDIDOCOL'] : $row['pedidosSelecionados'][0]['NRPEDIDOCOL'];
        $sql = "SELECT C.CDFILIAL, C.NRPEDIDOCOL, C.CDOPERADOR, O.NMOPERADOR, O.DSEMAILOPER, C.DTCOMENTARIO, C.TXCOMENTARIO FROM (SELECT * FROM COMENTPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDOCOL = :P_NRPEDIDOCOL AND CDOPERADOR = :P_CDOPERADOR ORDER BY DTCOMENTARIO DESC) C, OPERADOR O WHERE C.CDOPERADOR = O.CDOPERADOR AND ROWNUM = 1";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array(
                "P_CDFILIAL"     => $cdFilial,
                "P_NRPEDIDOCOL"  => $nrPedidoCol,
                "P_CDOPERADOR"   => $this->environment->getCdOperador()
            )
        );
        return($stmt->fetchAll()[0]);
    }
    
    public function infoOperador($row) {
        $comprador = isset($row['COMPRADOR']) ? $row['COMPRADOR'] : $row['pedidosSelecionados'][0]['COMPRADOR'];
        $sql = "SELECT CDOPERADOR, DSEMAILOPER, NMOPERADOR FROM OPERADOR WHERE CDOPERADOR = :CDOPERADOR";
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute(
            array("CDOPERADOR" => $comprador)
        );
        return($stmt->fetchAll()[0]);
    }
    
    public function getMessage($infoComentario) {
        $operador     = $infoComentario["NMOPERADOR"] ? $infoComentario["NMOPERADOR"] : $infoComentario["DSEMAILOPER"];
        $comentario   = nl2br($infoComentario["TXCOMENTARIO"]);
        $numeroPedido = $infoComentario["NRPEDIDOCOL"];
        $time         = explode(" ", $infoComentario["DTCOMENTARIO"]);
        $data         = $time[0];
        $hora         = $time[1];
        
        $message      = "<table>
                            <tr>
                                <td>"
                                    . $operador ." incluiu um novo comentário no pedido <b>" . $numeroPedido . "</b> em <b><span class='Object' id='OBJ_PREFIX_DWT71_com_zimbra_date'>" . $data . "</span> ". $hora ."</b>. 
                                </td>
                            </tr>
                            <tr>
                                <td class='title'> 
                                    <div>
                                        <br/> Comentário
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class='description'>
                                    <br/>" . $comentario .
                                "</td>
                            </tr>
                            <tr class='footer'>
                                <td>
                                    <center>
                                        <br> <p> Email automático enviado pelo Suprimentos. </p> 
                                    </center>
                                </td>
                            </tr>
                        </table>";
        return $message;
    }
    
    public function getMessageInconsistencia($infoComentario) {
        $operador     = $infoComentario["NMOPERADOR"] ? $infoComentario["NMOPERADOR"] : $infoComentario["DSEMAILOPER"];
        $numeroPedido = $infoComentario["NRPEDIDOCOL"];
        $time         = explode(" ", $infoComentario["DTCOMENTARIO"]);
        $data         = $time[0];
        $hora         = $time[1];
        
        $message      = "<table>
                            <tr>
                                <td class='title'> 
                                    <div>
                                        <br/> Comentário
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class='description'>"
                                    . $operador ." liberou as inconsistências do pedido <b>" . $numeroPedido . "</b> em <b><span class='Object' id='OBJ_PREFIX_DWT71_com_zimbra_date'>" . $data . "</span> ". $hora ."</b>. 
                                </td>
                            </tr>
                            <tr class='footer'>
                                <td>
                                    <center>
                                        <br> <p> Email automático enviado pelo Suprimentos. </p> 
                                    </center>
                                </td>
                            </tr>
                        </table>";
        return $message;
    }
    
    public function getMessageGerarCotação($nrPedido, $nmOperadorLogado) {
        $message      = "<table>
                            <tr>
                                <td class='title'>
                                    <div>
                                        <br/> Prezado Fornecedor,
                                    </div>
                                </td>
                            </tr>
                            <tr>
                                <td class='description'>
                                    <br/> Para prosseguirmos com o processo de cotação gentileza imprimir, assinar, scannear e anexar o relatório do pedido de número " . $nrPedido . " confirmando os preços negociados.
                                </td>
                            </tr>
                            <tr class='footer'>
                                <td>
                                    <center>
                                        <br>
                                        <p> Atenciosamente, </p>
                                        <p>" . $nmOperadorLogado . "</p>
                                    </center>
                                </td>
                            </tr>
                        </table>";
                    
        return $message;
    }
    
    public function getMessageIncluirExcluirRegião($infoComentario, $txEmail) {
        $operador     = $infoComentario["NMOPERADOR"];
        $comentario   = nl2br($txEmail);
        $time         = explode(" ", $infoComentario["DTCOMENTARIO"]);
        $data         = $time[0];
        $hora         = $time[1];
        
        $message      = "<table>
                            <tr>
                                <td>"
                                    . $comentario . "</b>
                                </td>
                            </tr>
                            <tr>
                                <td class='description'>
                                    <br/> Comentário incluído em <b><span class='Object' id='OBJ_PREFIX_DWT71_com_zimbra_date'>" . $data . "</span> ". $hora . " pelo operador" . $operador . "</b>. 
                                </td>
                            </tr>
                            <tr class='footer'>
                                <td>
                                    <center>
                                        <br> <p> E-mail automático enviado pelo Suprimentos. </p> 
                                    </center>
                                </td>
                            </tr>
                        </table>";
        return $message;
    }
   
    public function deletaLogacespedcol($cdfilial, $nrpedidocol) {
        
        $delete = "DELETE FROM LOGACESPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG";

        $params = [
            "CDFILIAL" => $cdfilial,
            "NRPEDIDOCOL" => $nrpedidocol,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($delete);
        $std->execute($params);
        
    }
   
    public function deletaComentpedcol($cdfilial, $nrpedidocol) {
        
        $delete = "DELETE FROM COMENTPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG";

        $params = [
            "CDFILIAL" => $cdfilial,
            "NRPEDIDOCOL" => $nrpedidocol,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($delete);
        $std->execute($params);
        
    }
   
    public function deletaPedcoleta($cdfilial, $nrpedcoleta, $cdforneced, $cdregiao) {
        
        $delete = "DELETE FROM PEDCOLETA WHERE CDFILIAL = :CDFILIAL AND NRPEDCOLETA = :NRPEDCOLETA AND CDFORNECED = :CDFORNECED AND CDREGIAO = :CDREGIAO AND NRORG = :NRORG";

        $params = [
            "CDFILIAL" => $cdfilial,
            "NRPEDCOLETA" => $nrpedcoleta,
            "CDFORNECED" => $cdforneced,
            "CDREGIAO" => $cdregiao,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($delete);
        $std->execute($params);
        
    }
   
    public function deletaItempedcol($cdfilial, $nrpedcoleta, $cdforneced, $cdregiao, $cdproduto = 'T', $cdmarca = 'T') {
        
        $delete = "DELETE FROM ITEMPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDCOLETA = :NRPEDCOLETA AND CDFORNECED = :CDFORNECED AND CDREGIAO = :CDREGIAO AND (CDPRODUTO = :CDPRODUTO OR :CDPRODUTO = 'T') AND (CDMARCA = :CDMARCA OR :CDMARCA = 'T') AND NRORG = :NRORG";

        $params = [
            "CDFILIAL" => $cdfilial,
            "NRPEDCOLETA" => $nrpedcoleta,
            "CDFORNECED" => $cdforneced,
            "CDREGIAO" => $cdregiao,
            "CDPRODUTO" => $cdproduto,
            "CDMARCA" => $cdmarca,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($delete);
        $std->execute($params);
        
    }
   
    public function deletaPrmarcpedcol($cdfilial, $nrpedidocol, $cdforneced) {
        
        $delete = "DELETE FROM PRMARCPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG AND NOT EXISTS(SELECT NRPEDCOLETA FROM PEDCOLETA WHERE CDFILIAL = :CDFILIAL AND CDFORNECED = :CDFORNECED AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG)";

        $params = [
            "CDFILIAL" => $cdfilial,
            "NRPEDIDOCOL" => $nrpedidocol,
            "CDFORNECED" => $cdforneced,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($delete);
        $std->execute($params);
        
    }
   
    public function deletaPedcolgeral($cdfilial, $nrpedidocol) {
        
        $delete = "DELETE FROM PEDCOLGERAL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG";

        $params = [
            "CDFILIAL" => $cdfilial,
            "NRPEDIDOCOL" => $nrpedidocol,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($delete);
        $std->execute($params);
        
    }
   
    public function deletaRegiaopedcol($cdfilial, $nrpedidocol, $cdregiao) {
        
        $delete = "DELETE FROM REGIAOPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND CDREGIAO = :CDREGIAO AND NRORG = :NRORG";

        $params = [
            "CDFILIAL" => $cdfilial,
            "NRPEDIDOCOL" => $nrpedidocol,
            "CDREGIAO" => $cdregiao,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($delete);
        $std->execute($params);
        
    }
   
    public function deletaFornepedcol($cdfilial, $nrpedidocol, $cdforneced) {
        
        $delete = "DELETE FROM FORNEPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND CDFORNECED = :CDFORNECED AND NRORG = :NRORG AND NOT EXISTS(SELECT NRPEDCOLETA FROM PEDCOLETA WHERE CDFILIAL = :CDFILIAL AND CDFORNECED = :CDFORNECED AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG)";

        $params = [
            "CDFILIAL" => $cdfilial,
            "NRPEDIDOCOL" => $nrpedidocol,
            "CDFORNECED" => $cdforneced,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($delete);
        $std->execute($params);
        
    }
    
    public function existAttachmentComment($cdFilial, $nrPedidoCol, $cdForneced, $nrPedColeta) {
        
        $query = "SELECT NRPEDIDOCOL, CDOPERADOR FROM COMENTPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND DSIDDOCFILESERV <> ' ' AND DSIDDOCFILESERV IS NOT NULL AND NRORG = :NRORG";

        $params = [
            "CDFILIAL" => $cdFilial,
            "NRPEDIDOCOL" => $nrPedidoCol,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        $commentsWithAttachment = $std->fetchAll();
        $fornecedor = false;
        $operadorLancamento = false;
        foreach ($commentsWithAttachment as $comment){
            $typeOperador = substr($comment['CDOPERADOR'], 0, 4) === '1099' ? 'fornecedor' : 'operadorLancamento';
            if($fornecedor === false){
                $fornecedor = $typeOperador === 'fornecedor' ? true : false;
            }
            if($operadorLancamento === false){
                $operadorLancamento = $typeOperador === 'operadorLancamento' ? true : false;
            }
        }
        if($fornecedor && $operadorLancamento){
            return true;
        }else if ($fornecedor && !$operadorLancamento){
            $this->alteraStatus($nrPedidoCol, $cdFilial, $cdForneced, $nrPedColeta);
            $this->commit();
            throw new \Exception("Existem pedidos pendentes de envio de aceite!", 13);
        }else if(!$fornecedor){
            return false;
        }
    }
    
    public function returnParamTermoAceite($cdforneced) {
        
        $query = "SELECT IDUTLCTRLTERMO FROM FORNECEDOR WHERE CDFORNECED = :CDFORNECED AND NRORG = :NRORG";

        $params = [
            "CDFORNECED" => $cdforneced,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];

        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        return $std->fetchAll()[0]['IDUTLCTRLTERMO'];
    }
    
    public function alteraStatus($nrPedido, $cdfilial, $cdForneced, $nrPedColeta, $rotina = false) {
        if($rotina === 'anexarAceiteGrid'){
            $idSituPedCol = 'A';
        }else if($rotina === 'inconsistencia'){
            $idSituPedCol = 'N';
        }else{
            $idSituPedCol = 'T';
            
            $params1 = [
                "NRPEDCOLETA" => $nrPedColeta,
                "CDFILIAL" => $cdfilial,
                "CDFORNECED" => $cdForneced,
                "NRORG" => $this->environment->getNrOrgTrab()
            ];
            $query2 = "UPDATE ITEMPEDCOL SET IDITPEDPRIONEG = 'S' WHERE NRPEDCOLETA = :NRPEDCOLETA AND CDFILIAL = :CDFILIAL AND CDFORNECED = :CDFORNECED AND NRORG = :NRORG";
            $executaQuery = $this->entityManager->getConnection()->prepare($query2);
            $executaQuery->execute($params1);
        }
        
        
        $params = [
            "IDSITUPEDCOL" => $idSituPedCol,
            "NRPEDIDOCOL" => $nrPedido,
            "CDFILIAL" => $cdfilial,
            "NRORG" => $this->environment->getNrOrgTrab()
        ];
        $query = "UPDATE PEDCOLGERAL SET IDSITUPEDCOLETA = :IDSITUPEDCOL , IDRENEGOCIAPCOL = 'S' WHERE CDFILIAL =:CDFILIAL AND NRPEDIDOCOL =:NRPEDIDOCOL AND NRORG =:NRORG";
        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        
        $query1 = "UPDATE PEDCOLETA SET IDSITUPEDCOL = :IDSITUPEDCOL WHERE CDFILIAL = :CDFILIAL AND NRPEDIDOCOL = :NRPEDIDOCOL AND NRORG = :NRORG";
        $stmt = $this->entityManager->getConnection()->prepare($query1);
        $stmt->execute($params);
        
    }
    
    
    public function pedidoColetaExists($params) {
        $query = "SELECT '1' FROM ITEMCOLE I WHERE I.CDFILIAL= :P_CDFILIAL AND INSTR( :P_NRPEDIDOCOL, I.NRPEDIDOCOL ) <> 0 AND (INSTR( :P_CDREGIAO, I.CDREGIAO ) <> 0 OR :P_CDREGIAO = 'T') AND INSTR( :P_CDFORNECED, I.CDFORNECED ) <> 0";
        
        $std = $this->entityManager->getConnection()->prepare($query);
        $std->execute($params);
        
        return $std->fetchAll();
    }
    
    public function filtroProdutosPedCol($row, $regioes){
        $filter = array(
            array(
    		    "columnName" => "P_CDREGIAO", 
    		    "value" => $regioes,
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDFORNECED", 
    		    "value" => $row['CDFORNECED'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_NRPEDIDOCOL", 
    		    "value" => $row['NRPEDIDOCOL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_NRPEDCOLETA", 
    		    "value" => $row['NRPEDCOLETA'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDCOMPRADOR", 
    		    "value" => $row['COMPRADOR'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTINIVALITM", 
    		    "value" => $row['DTINIPERGERAL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTFINVALITM", 
    		    "value" => $row['DTFINPERGERAL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDPRODINI", 
    		    "value" => '0',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDPRODFIN", 
    		    "value" => 'Z',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDMARCA", 
    		    "value" => 'T',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTINIVALANT", 
    		    "value" => '',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTFINVALANT", 
    		    "value" => '',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_MELHORPRECO", 
    		    "value" => '1',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $row['CDFILIAL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_IDVERIFICAVRIT", 
    		    "value" => 'N',
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "NRORG", 
    		    "value" => $this->environment->getNrorg(),
    		    "operator" => "="
    		)
    	);
    	return $filter;
    }
    
    public function filtroQtdeComprar($row, $regioes, $produtos){
        $filter = array(
            array(
    		    "columnName" => "P_CDREGIAO", 
    		    "value" => $regioes,
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDPRODUTO", 
    		    "value" => $produtos,
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTINI", 
    		    "value" => $row['DTINIPERGERAL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_DTFIN", 
    		    "value" => $row['DTFINPERGERAL'],
    		    "operator" => "="
		    ),
		    array(
    		    "columnName" => "P_CDFILIAL", 
    		    "value" => $row['CDFILIAL'],
    		    "operator" => "="
		    )
    	);
    	return $filter;
    }
    
    public function atualizaQtdeAComprar($row, $regioes, $fornecedores, $pedidos){
        $sql = "UPDATE ITEMPEDCOL
                   SET QTPRODPEDCOL  = :QTACOMP
                 WHERE CDFILIAL    = :P_CDFILIAL
                   AND CDPRODUTO   = :P_CDPRODUTO
                   AND INSTR(:P_CDREGIAO, CDREGIAO) > 0
                   AND INSTR(:P_NRPEDCOLETA, NRPEDCOLETA) > 0
                   AND INSTR(:P_CDFORNECED, CDFORNECED) > 0";
            
        $params = array(
                "QTACOMP"       => $row['QTACOMPRAR'],
                "P_CDFILIAL"    => $row['CDFILIAL'],
                "P_CDPRODUTO"   => $row['CDPRODUTO'],
                "P_CDREGIAO"    => $regioes,
                "P_NRPEDCOLETA" => $pedidos,
                "P_CDFORNECED"  => $fornecedores
            );
        
        $stmt = $this->entityManager->getConnection()->prepare($sql);
        $stmt->execute($params);
	}
	
	public function naoConsideraMarcaProd($nrlista, $paramcompreco) {
		$sql = "SELECT
                 PRODUTO.CDARVPROD,
                 PRODUTO.NMPRODUTO,
                 PRODUTO.CDPRODUTO,
                 PRODUTO.SGUNIDADE,
                 '*****' CDMARCA,
                 '*****' NMMARCA,
                 FORNECEDOR.NMFANTFORN,
                 PRODUTO.VRFATOCONV,
                 ROUND(DECODE(:PARAMCOMPPRECO,'E',NVL(PRMARCPEDCOL.VRPRECOOBJETIVO,0) / PRODUTO.VRFATOCONV,NVL(PRMARCPEDCOL.VRPRECOOBJETIVO,0
                 ) ),3) VRPRECOOBJETIVO,
                 PRMARCPEDCOL.DSOBSRENEGOCIA,
                 PRMARCPEDCOL.NRORG
             FROM
                 PRODUTO,
                 PRMARCPEDCOL,
                 PEDCOLETA,
                 FORNECEDOR,
                 LISTA
             WHERE
                 LISTA.NRLISTA =:NRLISTA
                 AND PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                 AND PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO
                 AND PRMARCPEDCOL.NRPEDIDOCOL = PEDCOLETA.NRPEDIDOCOL
                 AND PRMARCPEDCOL.CDFILIAL = PEDCOLETA.CDFILIAL
                 AND PEDCOLETA.CDFORNECED = FORNECEDOR.CDFORNECED
                 AND PRMARCPEDCOL.IDMELHORPRECO = 'S'
             ORDER BY
                 PRODUTO.NMPRODUTO";
        
        $params = array(
            "NRLISTA" => $nrlista,
            "PARAMCOMPPRECO" => $paramcompreco,
        );
        
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	
	public function consideraMarcaProd($nrlista, $paramcompreco) {
    	$sql = "SELECT
                 PRODUTO.CDARVPROD,
                 PRODUTO.NMPRODUTO,
                 PRODUTO.CDPRODUTO,
                 PRODUTO.SGUNIDADE,
                 MARCA.CDMARCA,
                 MARCA.NMMARCA,
                 FORNECEDOR.NMFANTFORN,
                 PRODUTO.VRFATOCONV,
                 ROUND(DECODE(:PARAMCOMPPRECO,'E',NVL(PRMARCPEDCOL.VRPRECOOBJETIVO,0) / PRODUTO.VRFATOCONV,NVL(PRMARCPEDCOL.VRPRECOOBJETIVO,0
                 ) ),3) VRPRECOOBJETIVO,
                 PRMARCPEDCOL.DSOBSRENEGOCIA,
                 PRMARCPEDCOL.NRORG
             FROM
                 PRODUTO,
                 MARCA,
                 PRMARCPEDCOL,
                 PEDCOLETA,
                 FORNECEDOR,
                 LISTA
             WHERE
                 LISTA.NRLISTA =:NRLISTA
                 AND PRMARCPEDCOL.CDFILIAL || PRMARCPEDCOL.NRPEDIDOCOL = LISTA.CDLISTA
                 AND PRMARCPEDCOL.CDPRODUTO = PRODUTO.CDPRODUTO
                 AND PRMARCPEDCOL.CDMARCA = MARCA.CDMARCA
                 AND PRMARCPEDCOL.NRPEDIDOCOL = PEDCOLETA.NRPEDIDOCOL
                 AND PRMARCPEDCOL.CDFILIAL = PEDCOLETA.CDFILIAL
                 AND PEDCOLETA.CDFORNECED = FORNECEDOR.CDFORNECED
                 AND PRMARCPEDCOL.IDMELHORPRECO = 'S'
             ORDER BY
                 PRODUTO.NMPRODUTO,
                 MARCA.NMMARCA";
        
        $params = array(
            "NRLISTA" => $nrlista,
            "PARAMCOMPPRECO" => $paramcompreco,
        );
        
    	return $this->entityManager->getConnection()->fetchAll($sql, $params);
    }
    
    public function incluirRegiao ($pedido, $regioes, $dtPedColeta, &$errorRegioes, &$regioesIncluidas) {
        foreach($regioes as $regiao) {
            try{
                $params = array(
                    "P_CDFILIAL" => $pedido["CDFILIAL"],
                    "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"],
                    "P_CDREGIAO" => $regiao['CDREGIAO']
                );
                $sql = "INSERT INTO REGIAOPEDCOL (CDFILIAL, NRPEDIDOCOL, CDREGIAO) VALUES ( :P_CDFILIAL, :P_NRPEDIDOCOL, :P_CDREGIAO )";
                $stmt = $this->entityManager->getConnection()->prepare($sql);
                $stmt->execute($params);
            
                $params1 = array(
                    "P_CDFILIAL" => $pedido["CDFILIAL"],
                    "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"]
                );
                $sql1 = "SELECT CDFORNECED FROM FORNEPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDOCOL = :P_NRPEDIDOCOL";
                $stmt = $this->entityManager->getConnection()->prepare($sql1);
                $stmt->execute($params1);
                $cdForneced = $stmt->fetchAll()[0]['CDFORNECED'];
                
                $tableFilialFornecedRegiao = 'PEDCOLETA' . $pedido["CDFILIAL"] . $cdForneced . $regiao['CDREGIAO'];
                
                $stProximoCodigo = $this->newCode->getCodeByTableName($tableFilialFornecedRegiao, $this->environment->getNrOrg());
                $params2 = array(
                    "P_CDFILIAL" => $pedido["CDFILIAL"],
                    "P_NRPEDCOLETA" => $stProximoCodigo,
                    "P_CDFORNECED" => $pedido["CDFORNECED"],
                    "P_DTPEDCOLETA" => $dtPedColeta,
                    "P_CDOPERADOR" => $pedido["COMPRADOR"],
                    "P_DTINIPERCOT" => $pedido["DTINIPERGERAL"],
                    "P_DTFINPERCOT" => $pedido["DTFINPERGERAL"],
                    "P_CDREGIAO" => $regiao['CDREGIAO'],
                    "P_CDLEILAO" => null,
                    "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"]
                );
                
                $sql2 = "INSERT INTO PEDCOLETA (CDFILIAL, NRPEDCOLETA, CDFORNECED, DTPEDCOLETA, CDOPERADOR, DTINIPERCOT, DTFINPERCOT, CDREGIAO, CDLEILAO, NRPEDIDOCOL) VALUES (:P_CDFILIAL, :P_NRPEDCOLETA, :P_CDFORNECED, :P_DTPEDCOLETA , :P_CDOPERADOR, :P_DTINIPERCOT, :P_DTFINPERCOT, :P_CDREGIAO, :P_CDLEILAO, :P_NRPEDIDOCOL)";
                $stmt = $this->entityManager->getConnection()->prepare($sql2);
                $stmt->execute($params2);
                
                $params3 = array(
                    "P_CDFILIAL" => $pedido["CDFILIAL"],
                    "P_NRPEDCOLETA" => $stProximoCodigo,
                    "P_CDFORNECED" => $pedido["CDFORNECED"],
                    "P_CDREGIAO" => $regiao['CDREGIAO'],
                    "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"]
                );
                $sql3 = "INSERT INTO ITEMPEDCOL(CDFILIAL, NRPEDCOLETA, CDFORNECED, CDREGIAO, CDPRODUTO, CDMARCA, VRITEMPEDCOL, VRANTITPEDCOL) SELECT :P_CDFILIAL, :P_NRPEDCOLETA, :P_CDFORNECED, :P_CDREGIAO, PRMARCPEDCOL.CDPRODUTO, PRMARCPEDCOL.CDMARCA, PRMARCPEDCOL.VRPRECUNIPRMARC, PRMARCPEDCOL.VRULTPRECPRMARC FROM PRMARCPEDCOL WHERE PRMARCPEDCOL.CDFILIAL = :P_CDFILIAL AND PRMARCPEDCOL.NRPEDIDOCOL = :P_NRPEDIDOCOL";
                $stmt = $this->entityManager->getConnection()->prepare($sql3);
                $stmt->execute($params3);
                array_push($regioesIncluidas, array("CDREGIAO" => $regiao["CDREGIAO"], "NMREGIAO" => $regiao["NMREGIAO"]));
            } catch(\Exception $e){
                if(strpos($e->getMessage(), 'ORA-00001')){
                    array_push($errorRegioes, array( "NRPEDIDOCOL" => "Pedido: " . $pedido['NRPEDIDOCOL'], "REGIAO" => "Região: " . $regiao["CDREGIAO"] . " - " . $regiao["NMREGIAO"]));
                }
            }
         }
    }
    
    public function excluirRegiao ($pedido, $regioes, &$errorRegioes, &$regioesExcluidas) {
        foreach($regioes as $regiao) {
            $params = array(
                "P_CDFILIAL" => $pedido["CDFILIAL"],
                "P_NRPEDIDOCOL" => $pedido["NRPEDIDOCOL"],
                "P_CDREGIAO" => $regiao['CDREGIAO']
            );
            
            
            $sql = "SELECT * FROM REGIAOPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDOCOL = :P_NRPEDIDOCOL AND CDREGIAO = :P_CDREGIAO";
            $stmt = $this->entityManager->getConnection()->prepare($sql);
            $stmt->execute($params);
            $regionExists = $stmt->fetchAll();
            //if(count($regionExists) > 0){
            if (((is_array($regionExists) && !is_null($regionExists)) ? count($regionExists) : 0) > 0) {
                $sql1 = "DELETE FROM REGIAOPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDOCOL = :P_NRPEDIDOCOL AND CDREGIAO = :P_CDREGIAO";
                $stmt = $this->entityManager->getConnection()->prepare($sql1);
                $stmt->execute($params);
                
                $sql2 = "DELETE FROM ITEMPEDCOL WHERE CDFILIAL = :P_CDFILIAL AND CDREGIAO = :P_CDREGIAO AND EXISTS (SELECT 1 FROM PEDCOLETA WHERE PEDCOLETA.CDFILIAL = :P_CDFILIAL AND PEDCOLETA.NRPEDIDOCOL = :P_NRPEDIDOCOL AND PEDCOLETA.CDREGIAO =:P_CDREGIAO AND PEDCOLETA.CDFILIAL = ITEMPEDCOL.CDFILIAL AND PEDCOLETA.CDFORNECED = ITEMPEDCOL.CDFORNECED AND PEDCOLETA.NRPEDCOLETA = ITEMPEDCOL.NRPEDCOLETA AND PEDCOLETA.CDREGIAO = ITEMPEDCOL.CDREGIAO)";
                $stmt = $this->entityManager->getConnection()->prepare($sql2);
                $stmt->execute($params);
            
                $sql3 = "DELETE FROM PEDCOLETA WHERE CDFILIAL = :P_CDFILIAL AND NRPEDIDOCOL = :P_NRPEDIDOCOL AND CDREGIAO = :P_CDREGIAO";
                $stmt = $this->entityManager->getConnection()->prepare($sql3);
                $stmt->execute($params);
                array_push($regioesExcluidas, array("CDREGIAO" => $regiao["CDREGIAO"], "NMREGIAO" => $regiao["NMREGIAO"]));
            }else{
                array_push($errorRegioes, array( "NRPEDIDOCOL" => "Pedido: " . $pedido['NRPEDIDOCOL'], "REGIAO" => "Região: " . $regiao["CDREGIAO"] . " - " . $regiao["NMREGIAO"]));
            }
         }
    }
}